from django.http import HttpResponse


def optimize_user(request, username):
    access_allowed = True
    if request.user.username != username:
        access_allowed = False

    if access_allowed:
        return HttpResponse(request.user.password, content_type='text/plain')

    # Guess not!
    return HttpResponse(status=403)



from django.conf.urls import patterns, url
import asheeshs_django_optimizer.views

urlpatterns = patterns(
    '',  # namespace parameter; ignored for our purposes

    (r'^optimize_user/(.+)$', asheeshs_django_optimizer.views.optimize_user),
)
